@@ -1,31 +1,16 @@
 """Python multiprocessing fork"""
-
-from __future__ import absolute_import
-
-VERSION = (2, 7, 3, 2)
-__version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
-__author__ = 'R Oudkerk / Python Software Foundation'
-__author_email__ = 'python-dev@python.org'
-__maintainer__ = 'Ask Solem',
-__contact__ = "ask@celeryproject.org"
-__homepage__ = "http://github.com/ask/billiard"
-__docformat__ = "restructuredtext"
-
-# -eof meta-
-
-
 #
 # Package analogous to 'threading.py' but using processes
 #
-# billiard/__init__.py
+# multiprocessing/__init__.py
 #
 # This package is intended to duplicate the functionality (and much of
 # the API) of threading.py but uses processes instead of threads.  A
-# subpackage 'billiard.dummy' has the same API but is a simple
+# subpackage 'multiprocessing.dummy' has the same API but is a simple
 # wrapper for 'threading'.
 #
-# Try calling `billiard.doc.main()` to read the html
-# documentation in in a webbrowser.
+# Try calling `multiprocessing.doc.main()` to read the html
+# documentation in a webbrowser.
 #
 #
 # Copyright (c) 2006-2008, R Oudkerk
@@ -54,8 +39,23 @@ __docformat__ = "restructuredtext"
 # HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 # LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+# SUCH DAMAGE.
 #
 
+from __future__ import absolute_import
+from __future__ import with_statement
+
+VERSION = (2, 7, 3, 3)
+__version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
+__author__ = 'R Oudkerk / Python Software Foundation'
+__author_email__ = 'python-dev@python.org'
+__maintainer__ = 'Ask Solem',
+__contact__ = "ask@celeryproject.org"
+__homepage__ = "http://github.com/ask/billiard"
+__docformat__ = "restructuredtext"
+
+# -eof meta-
+
 __all__ = [
     'Process', 'current_process', 'active_children', 'freeze_support',
     'Manager', 'Pipe', 'cpu_count', 'log_to_stderr', 'get_logger',
@@ -73,32 +73,26 @@ __all__ = [
 import os
 import sys
 
+from .exceptions import (  # noqa
+    ProcessError,
+    BufferTooShort,
+    TimeoutError,
+    AuthenticationError,
+    TimeLimitExceeded,
+    SoftTimeLimitExceeded,
+    WorkerLostError,
+)
 from .process import Process, current_process, active_children
 from .util import SUBDEBUG, SUBWARNING
 
-#
-# Exceptions
-#
-
-class ProcessError(Exception):
-    pass
-
-class BufferTooShort(ProcessError):
-    pass
-
-class TimeoutError(ProcessError):
-    pass
-
-class AuthenticationError(ProcessError):
-    pass
-
 # This is down here because _billiard uses BufferTooShort
-import _billiard
+from ._ext import supports_exec
 
 #
 # Definitions not depending on native semaphores
 #
 
+
 def Manager():
     '''
     Returns a manager associated with a running server process
@@ -111,6 +105,7 @@ def Manager():
     m.start()
     return m
 
+
 def Pipe(duplex=True):
     '''
     Returns two connection object connected by a pipe
@@ -118,6 +113,7 @@ def Pipe(duplex=True):
     from .connection import Pipe
     return Pipe(duplex)
 
+
 def cpu_count():
     '''
     Returns the number of CPUs in the system
@@ -128,8 +124,12 @@ def cpu_count():
         except (ValueError, KeyError):
             num = 0
     elif 'bsd' in sys.platform or sys.platform == 'darwin':
+        comm = '/sbin/sysctl -n hw.ncpu'
+        if sys.platform == 'darwin':
+            comm = '/usr' + comm
         try:
-            num = int(os.popen('sysctl -n hw.ncpu').read())
+            with os.popen(comm) as p:
+                num = int(p.read())
         except ValueError:
             num = 0
     else:
@@ -143,6 +143,7 @@ def cpu_count():
     else:
         raise NotImplementedError('cannot determine number of cpus')
 
+
 def freeze_support():
     '''
     Check whether this is a fake forked process in a frozen executable.
@@ -152,6 +153,7 @@ def freeze_support():
         from .forking import freeze_support
         freeze_support()
 
+
 def get_logger():
     '''
     Return package logger -- if it does not already exist then it is created
@@ -159,6 +161,7 @@ def get_logger():
     from .util import get_logger
     return get_logger()
 
+
 def log_to_stderr(level=None):
     '''
     Turn on logging and add a handler which prints to stderr
@@ -166,16 +169,18 @@ def log_to_stderr(level=None):
     from .util import log_to_stderr
     return log_to_stderr(level)
 
+
 def allow_connection_pickling():
     '''
     Install support for sending connections and sockets between processes
     '''
-    from . import reduction
+    from . import reduction  # noqa
 
 #
 # Definitions depending on native semaphores
 #
 
+
 def Lock():
     '''
     Returns a non-recursive lock object
@@ -183,6 +188,7 @@ def Lock():
     from .synchronize import Lock
     return Lock()
 
+
 def RLock():
     '''
     Returns a recursive lock object
@@ -190,6 +196,7 @@ def RLock():
     from .synchronize import RLock
     return RLock()
 
+
 def Condition(lock=None):
     '''
     Returns a condition object
@@ -197,6 +204,7 @@ def Condition(lock=None):
     from .synchronize import Condition
     return Condition(lock)
 
+
 def Semaphore(value=1):
     '''
     Returns a semaphore object
@@ -204,6 +212,7 @@ def Semaphore(value=1):
     from .synchronize import Semaphore
     return Semaphore(value)
 
+
 def BoundedSemaphore(value=1):
     '''
     Returns a bounded semaphore object
@@ -211,6 +220,7 @@ def BoundedSemaphore(value=1):
     from .synchronize import BoundedSemaphore
     return BoundedSemaphore(value)
 
+
 def Event():
     '''
     Returns an event object
@@ -218,6 +228,7 @@ def Event():
     from .synchronize import Event
     return Event()
 
+
 def Queue(maxsize=0):
     '''
     Returns a queue object
@@ -225,6 +236,7 @@ def Queue(maxsize=0):
     from .queues import Queue
     return Queue(maxsize)
 
+
 def JoinableQueue(maxsize=0):
     '''
     Returns a queue object
@@ -232,6 +244,7 @@ def JoinableQueue(maxsize=0):
     from .queues import JoinableQueue
     return JoinableQueue(maxsize)
 
+
 def Pool(processes=None, initializer=None, initargs=(), maxtasksperchild=None):
     '''
     Returns a process pool object
@@ -239,6 +252,7 @@ def Pool(processes=None, initializer=None, initargs=(), maxtasksperchild=None):
     from .pool import Pool
     return Pool(processes, initializer, initargs, maxtasksperchild)
 
+
 def RawValue(typecode_or_type, *args):
     '''
     Returns a shared object
@@ -246,6 +260,7 @@ def RawValue(typecode_or_type, *args):
     from .sharedctypes import RawValue
     return RawValue(typecode_or_type, *args)
 
+
 def RawArray(typecode_or_type, size_or_initializer):
     '''
     Returns a shared array
@@ -253,6 +268,7 @@ def RawArray(typecode_or_type, size_or_initializer):
     from .sharedctypes import RawArray
     return RawArray(typecode_or_type, size_or_initializer)
 
+
 def Value(typecode_or_type, *args, **kwds):
     '''
     Returns a synchronized shared object
@@ -260,6 +276,7 @@ def Value(typecode_or_type, *args, **kwds):
     from .sharedctypes import Value
     return Value(typecode_or_type, *args, **kwds)
 
+
 def Array(typecode_or_type, size_or_initializer, **kwds):
     '''
     Returns a synchronized shared array
@@ -271,6 +288,7 @@ def Array(typecode_or_type, size_or_initializer, **kwds):
 #
 #
 
+
 def set_executable(executable):
     '''
     Sets the path to a python.exe or pythonw.exe binary used to run
@@ -280,6 +298,7 @@ def set_executable(executable):
     from .forking import set_executable
     set_executable(executable)
 
+
 def forking_is_enabled():
     '''
     Returns a boolean value indicating whether billiard is
@@ -292,6 +311,7 @@ def forking_is_enabled():
     from . import forking
     return forking._forking_is_enabled
 
+
 def forking_enable(value):
     '''
     Enable/disable creation of child process by forking the current process.
@@ -301,7 +321,8 @@ def forking_enable(value):
     On systems with `os.fork()` forking is enabled by default, and on
     other systems it is always disabled.
     '''
-    from . import forking
-    if value and not hasattr(os, 'fork'):
-        raise ValueError('os.fork() not found')
-    forking._forking_is_enabled = bool(value)
+    if not value and supports_exec:
+        from . import forking
+        if value and not hasattr(os, 'fork'):
+            raise ValueError('os.fork() not found')
+        forking._forking_is_enabled = bool(value)
